@@ -336,14 +336,12 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
 }
 
 static string
-cal_put_age_on_summary(const time_t& born,
+cal_put_age_on_summary(const int& born,
 		       const time_t& birthday,
 		       const string& summary)
 {
-  struct tm* birthday_time = localtime(&birthday);
-  int age = birthday_time->tm_year;
-  birthday_time = localtime(&born); 
-  age -= birthday_time->tm_year;
+  struct tm* birthday_time = localtime(&birthday); 
+  int age = 1900 + birthday_time->tm_year - born;
   gchar* new_summary_c = g_strdup_printf("%s (%d)", summary.c_str(), age);
   string new_summary(new_summary_c);
   g_free(new_summary_c);
@@ -405,7 +403,7 @@ cal_read_ccompnents_for_calendar(CCalendar* calendar,
 	    if(c->getType() == 4 &&
 	       desktop_plugin->show_age)
 	    {
-	      string new_summary = cal_put_age_on_summary(component->getDateStart(), 
+	      string new_summary = cal_put_age_on_summary(component->getStatus(), 
 							  c->getDateStart(),
 							  c->getSummary());
 	      c->setSummary(new_summary);
