@@ -25,6 +25,7 @@
 #define CAL_HP_KEY_CAL_ROW_COUNT "cal_row_count"
 #define CAL_HP_KEY_CAL_TIME_PERIOD "cal_time_period"
 #define CAL_HP_KEY_CAL_SHOW_AGE "cal_show_age"
+#define CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE "update_if_visible"
 #define CAL_HOME_PLUGIN_SETTINGS_FILE "/.cal_home_widget"
 
 void 
@@ -75,6 +76,14 @@ cal_home_read_settings(CalHomePlugin *desktop_plugin)
 							CAL_HP_KEY_CAL_SHOW_AGE,
 							NULL);
     }
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE, NULL))
+    {
+      desktop_plugin->update_if_visible = g_key_file_get_boolean(keyFile, 
+								 desktop_plugin->iD, 
+								 CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE,
+								 NULL);
+    }
+
   }
   g_key_file_free(keyFile);
   g_free(fileName);
@@ -100,6 +109,8 @@ cal_home_save_settings(CalHomePlugin* desktop_plugin)
   g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_ROW_COUNT, desktop_plugin->cal_row_count);
   g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_TIME_PERIOD, desktop_plugin->cal_time_period);
   g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_AGE, desktop_plugin->show_age);
+  g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE, desktop_plugin->update_if_visible);
+
   fileData = g_key_file_to_data (keyFile, &size, NULL);
   g_file_set_contents(filename, fileData, size, NULL);
 
