@@ -154,7 +154,7 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
 				       dgettext("hildon-libs", "wdgt_bd_done"),
 				       GTK_RESPONSE_ACCEPT,
 				       NULL);
-
+  gtk_window_set_default_size(GTK_WINDOW(dialog), -1, 325);
   GtkWidget *cal_time_selector = hildon_touch_selector_new_text();
   GtkWidget *launch_view_selector = hildon_touch_selector_new_text();
   GtkWidget *cal_size_selector = hildon_touch_selector_new_text();
@@ -223,7 +223,15 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
 			       desktop_plugin->show_age);
 
   gtk_button_set_label(GTK_BUTTON(show_age),
-		       "Show age");
+		       "Show persons age");
+
+  GtkWidget* update_if_visible = hildon_gtk_toggle_button_new(HILDON_SIZE_FINGER_HEIGHT);
+
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(update_if_visible),
+			       desktop_plugin->update_if_visible);
+
+  gtk_button_set_label(GTK_BUTTON(update_if_visible),
+		       "Update when switch to the desktop");
 
   hildon_button_set_style(HILDON_BUTTON(visible_calendar),
 			  HILDON_BUTTON_STYLE_PICKER);
@@ -276,14 +284,17 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
   g_signal_connect(G_OBJECT(visible_calendar), "clicked", 
 		   G_CALLBACK(show_visible_calendars_dlg), settings_data);
   
+  GtkWidget* pan = hildon_pannable_area_new();
+  GtkWidget* pan_content = gtk_vbox_new(TRUE, 3);
   GtkWidget* content = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
-
-  gtk_box_pack_start(GTK_BOX(content), cal_time_button, FALSE, FALSE, 3);
-  gtk_box_pack_start(GTK_BOX(content), cal_size_button, FALSE, FALSE, 3);
-  gtk_box_pack_start(GTK_BOX(content), open_mode_button, FALSE, FALSE, 3);
-  gtk_box_pack_start(GTK_BOX(content), visible_calendar, FALSE, FALSE, 3);
-  gtk_box_pack_start(GTK_BOX(content), show_age, FALSE, FALSE, 3);
-
+  gtk_box_pack_start(GTK_BOX(pan_content), cal_time_button, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), cal_size_button, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), open_mode_button, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), visible_calendar, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), show_age, FALSE, FALSE, 3);
+  gtk_box_pack_start(GTK_BOX(pan_content), update_if_visible, FALSE, FALSE, 3);
+  hildon_pannable_area_add_with_viewport(HILDON_PANNABLE_AREA(pan), pan_content);
+  gtk_container_add(GTK_CONTAINER(content), pan);
   gtk_widget_show_all(dialog);
 
   if(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
@@ -299,6 +310,7 @@ cal_show_settings_dialog(GtkWidget* widget, gpointer data)
       desktop_plugin->cal_row_count = row_count;
     desktop_plugin->cal_time_period = CalTimePeriod(hildon_touch_selector_get_active(HILDON_TOUCH_SELECTOR(cal_time_selector), 0));
     desktop_plugin->show_age = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(show_age));
+    desktop_plugin->update_if_visible = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(update_if_visible));
     cal_home_save_settings(desktop_plugin);
     cal_home_load_db_events(desktop_plugin);
     cal_widget_resize_for_cal_size(desktop_plugin);
