@@ -309,6 +309,7 @@ cal_on_current_desktop(GtkWidget* widget,
   if(on)
   {
     if(time_to_update(desktop_plugin) ||
+       desktop_plugin->update_if_visible || 
        desktop_plugin->update_view)
     {
       calendar_update_view(desktop_plugin);
@@ -650,6 +651,7 @@ cal_home_plugin_init(CalHomePlugin *desktop_plugin)
   desktop_plugin->time_to_update = mktime(&update_date);
   desktop_plugin->press_time = 0;
   desktop_plugin->update_view = TRUE;
+  desktop_plugin->update_if_visible = FALSE;
   desktop_plugin->has_24_time_format = cal_24_time_format();
   desktop_plugin->show_age = FALSE;
   GtkWidget *contents = build_ui(desktop_plugin);
